@@ -1,9 +1,9 @@
 
-#include "libvideogfx/x11/imgwin.hh"
-#include "libvideogfx/graphics/fileio/jpeg.hh"
-#include "libvideogfx/graphics/draw/blit.hh"
-#include "libvideogfx/graphics/draw/format.hh"
-#include "libvideogfx/graphics/draw/scale.hh"
+#include "../libvideogfx/x11/imgwin.hh"
+#include "../libvideogfx/graphics/fileio/jpeg.hh"
+#include "../libvideogfx/graphics/draw/blit.hh"
+#include "../libvideogfx/graphics/draw/format.hh"
+#include "../libvideogfx/graphics/draw/scale.hh"
 using namespace videogfx;
 
 #include <unistd.h>
