@@ -3,7 +3,7 @@
  */
 
 #include "config.h"
-#include "libvideogfx/libvideogfx.hh"
+#include "../libvideogfx/libvideogfx.hh"
 
 #include <iostream>
 using namespace std;
