@@ -1,8 +1,11 @@
 // use option -xv to open image with Xv extension
 
-#include "libvideogfx/x11/imgwin.hh"
-#include "libvideogfx/x11/draw_x11.hh"
+#include "../libvideogfx/x11/imgwin.hh"
+#include "../libvideogfx/x11/draw_x11.hh"
+#include <iostream>
+
 using namespace videogfx;
+using namespace std;
 
 #include <unistd.h>
 
@@ -40,6 +43,21 @@ int main(int argc,char** argv)
   win.Create(256,256,"test");
   win.Display(img);
 
+  for (;;)
+    {
+      int x,y;
+      if (win.CheckForMouseMove(x,y))
+	{
+	  cout << "mouse: " << x << ";" << y << endl;
+	}
+
+      char c;
+      if (c=win.CheckForKeypress())
+	{
+	  cout << "key: '" << c << "' " << endl;
+	}
+    }
+
   sleep(10);
 
   return 0;
